summaryrefslogtreecommitdiff
path: root/EdkUnixPkg/Dxe
diff options
context:
space:
mode:
authorbbahnsen <bbahnsen@6f19259b-4bc3-4df7-8a09-765794883524>2007-01-07 19:31:19 +0000
committerbbahnsen <bbahnsen@6f19259b-4bc3-4df7-8a09-765794883524>2007-01-07 19:31:19 +0000
commit377fc2ae7125fec78f349c1ceda0cbeb53c988c2 (patch)
tree187123e38fa0c4cbc12368ed9c4d32f5e3c2a394 /EdkUnixPkg/Dxe
parent6bb60d710b3e041221582400390eca5977cd9aca (diff)
downloadedk2-platforms-377fc2ae7125fec78f349c1ceda0cbeb53c988c2.tar.xz
Change many windows references to unix.
git-svn-id: https://edk2.svn.sourceforge.net/svnroot/edk2/trunk/edk2@2186 6f19259b-4bc3-4df7-8a09-765794883524
Diffstat (limited to 'EdkUnixPkg/Dxe')
-rw-r--r--EdkUnixPkg/Dxe/UnixThunk/Bus/BlockIo/UnixBlockIo.c8
-rw-r--r--EdkUnixPkg/Dxe/UnixThunk/Bus/BlockIo/UnixBlockIo.h4
-rw-r--r--EdkUnixPkg/Dxe/UnixThunk/Bus/Console/Console.c2
-rw-r--r--EdkUnixPkg/Dxe/UnixThunk/Bus/Console/Console.h4
-rw-r--r--EdkUnixPkg/Dxe/UnixThunk/Bus/Console/ConsoleIn.c2
-rw-r--r--EdkUnixPkg/Dxe/UnixThunk/Bus/Console/ConsoleOut.c4
-rw-r--r--EdkUnixPkg/Dxe/UnixThunk/Bus/SimpleFileSystem/UnixSimpleFileSystem.c8
-rw-r--r--EdkUnixPkg/Dxe/UnixThunk/Bus/Uga/UnixUga.h2
-rw-r--r--EdkUnixPkg/Dxe/UnixThunk/Bus/UnixBusDriver/UnixBusDriver.c10
-rw-r--r--EdkUnixPkg/Dxe/UnixThunk/Bus/UnixBusDriver/UnixBusDriver.h4
-rw-r--r--EdkUnixPkg/Dxe/UnixThunk/Bus/UnixBusDriver/UnixBusDriver.msa2
-rw-r--r--EdkUnixPkg/Dxe/UnixThunk/Chipset/Metronome/Metronome.c2
-rw-r--r--EdkUnixPkg/Dxe/UnixThunk/Chipset/Metronome/Metronome.h2
-rw-r--r--EdkUnixPkg/Dxe/UnixThunk/Chipset/RealTimeClock/RealTimeClock.c2
-rw-r--r--EdkUnixPkg/Dxe/UnixThunk/Chipset/Reset/Reset.c2
-rw-r--r--EdkUnixPkg/Dxe/UnixThunk/Chipset/Timer/Timer.c4
-rw-r--r--EdkUnixPkg/Dxe/UnixThunk/Chipset/Timer/Timer.h4
-rw-r--r--EdkUnixPkg/Dxe/UnixThunk/Cpu/Cpu.c6
-rw-r--r--EdkUnixPkg/Dxe/UnixThunk/Cpu/CpuDriver.h2
19 files changed, 37 insertions, 37 deletions
diff --git a/EdkUnixPkg/Dxe/UnixThunk/Bus/BlockIo/UnixBlockIo.c b/EdkUnixPkg/Dxe/UnixThunk/Bus/BlockIo/UnixBlockIo.c
index ca4a5f2ff8..81dd20661b 100644
--- a/EdkUnixPkg/Dxe/UnixThunk/Bus/BlockIo/UnixBlockIo.c
+++ b/EdkUnixPkg/Dxe/UnixThunk/Bus/BlockIo/UnixBlockIo.c
@@ -15,8 +15,8 @@ Module Name:
Abstract:
- Produce block IO abstractions for real devices on your PC using Win32 APIs.
- The configuration of what devices to mount or emulate comes from NT
+ Produce block IO abstractions for real devices on your PC using Posix APIs.
+ The configuration of what devices to mount or emulate comes from UNIX
environment variables. The variables must be visible to the Microsoft*
Developer Studio for them to work.
@@ -27,7 +27,7 @@ Abstract:
<block count> - Decimal number of blocks a device supports.
<block size> - Decimal number of bytes per block.
- NT envirnonment variable contents. '<' and '>' are not part of the variable,
+ UNIX envirnonment variable contents. '<' and '>' are not part of the variable,
they are just used to make this help more readable. There should be no
spaces between the ';'. Extra spaces will break the variable. A '!' is
used to seperate multiple devices in a variable.
@@ -47,7 +47,7 @@ Abstract:
A 1.44MB emulated floppy with a block size of 1024 would look like:
EFI_UNIX_VIRTUAL_DISKS=RW;1440;1024
- Physical Disks: These devices use NT to open a real device in your system
+ Physical Disks: These devices use UNIX to open a real device in your system
Thus a 120 MB floppy would look like:
EFI_UNIX_PHYSICAL_DISKS=B:RW;245760;512
diff --git a/EdkUnixPkg/Dxe/UnixThunk/Bus/BlockIo/UnixBlockIo.h b/EdkUnixPkg/Dxe/UnixThunk/Bus/BlockIo/UnixBlockIo.h
index 70d8571c3c..8cdc9a97d5 100644
--- a/EdkUnixPkg/Dxe/UnixThunk/Bus/BlockIo/UnixBlockIo.h
+++ b/EdkUnixPkg/Dxe/UnixThunk/Bus/BlockIo/UnixBlockIo.h
@@ -15,8 +15,8 @@ Module Name:
Abstract:
- Produce block IO abstractions for real devices on your PC using Win32 APIs.
- The configuration of what devices to mount or emulate comes from NT
+ Produce block IO abstractions for real devices on your PC using Posix APIs.
+ The configuration of what devices to mount or emulate comes from UNIX
environment variables. The variables must be visible to the Microsoft*
Developer Studio for them to work.
diff --git a/EdkUnixPkg/Dxe/UnixThunk/Bus/Console/Console.c b/EdkUnixPkg/Dxe/UnixThunk/Bus/Console/Console.c
index cd4870d502..79558a88d9 100644
--- a/EdkUnixPkg/Dxe/UnixThunk/Bus/Console/Console.c
+++ b/EdkUnixPkg/Dxe/UnixThunk/Bus/Console/Console.c
@@ -15,7 +15,7 @@ Module Name:
Abstract:
- Console based on Win32 APIs.
+ Console based on Posix APIs.
--*/
diff --git a/EdkUnixPkg/Dxe/UnixThunk/Bus/Console/ConsoleIn.c b/EdkUnixPkg/Dxe/UnixThunk/Bus/Console/ConsoleIn.c
index ff70a5fd8e..0a7503fe6e 100644
--- a/EdkUnixPkg/Dxe/UnixThunk/Bus/Console/ConsoleIn.c
+++ b/EdkUnixPkg/Dxe/UnixThunk/Bus/Console/ConsoleIn.c
@@ -15,7 +15,7 @@ Module Name:
Abstract:
- Console based on Win32 APIs.
+ Console based on Posix APIs.
This file attaches a SimpleTextIn protocol to a previously open window.
diff --git a/EdkUnixPkg/Dxe/UnixThunk/Bus/Console/ConsoleOut.c b/EdkUnixPkg/Dxe/UnixThunk/Bus/Console/ConsoleOut.c
index bd9d4e29fe..5fbc77e51d 100644
--- a/EdkUnixPkg/Dxe/UnixThunk/Bus/Console/ConsoleOut.c
+++ b/EdkUnixPkg/Dxe/UnixThunk/Bus/Console/ConsoleOut.c
@@ -15,9 +15,9 @@ Module Name:
Abstract:
- Console based on Win32 APIs.
+ Console based on Posix APIs.
- This file creates an Win32 window and attaches a SimpleTextOut protocol.
+ This file creates an Posix window and attaches a SimpleTextOut protocol.
--*/
diff --git a/EdkUnixPkg/Dxe/UnixThunk/Bus/Uga/UnixUga.h b/EdkUnixPkg/Dxe/UnixThunk/Bus/Uga/UnixUga.h
index c34768d5c6..0ea88e5d02 100644
--- a/EdkUnixPkg/Dxe/UnixThunk/Bus/Uga/UnixUga.h
+++ b/EdkUnixPkg/Dxe/UnixThunk/Bus/Uga/UnixUga.h
@@ -136,7 +136,7 @@ Returns:
;
//
-// EFI 1.1 driver model prototypes for Win NT UGA
+// EFI 1.1 driver model prototypes for Win UNIX UGA
//
EFI_STATUS
diff --git a/EdkUnixPkg/Dxe/UnixThunk/Bus/UnixBusDriver/UnixBusDriver.h b/EdkUnixPkg/Dxe/UnixThunk/Bus/UnixBusDriver/UnixBusDriver.h
index 4d8530bc8f..da9a9ac690 100644
--- a/EdkUnixPkg/Dxe/UnixThunk/Bus/UnixBusDriver/UnixBusDriver.h
+++ b/EdkUnixPkg/Dxe/UnixThunk/Bus/UnixBusDriver/UnixBusDriver.h
@@ -37,7 +37,7 @@ EFI_UNIX_PASS_THRU - associates a device with our PCI support
<block count> - Decimal number of blocks a device supports.
<block size> - Decimal number of bytes per block.
- NT envirnonment variable contents. '<' and '>' are not part of the variable,
+ UNIX envirnonment variable contents. '<' and '>' are not part of the variable,
they are just used to make this help more readable. There should be no
spaces between the ';'. Extra spaces will break the variable. A '!' is
used to seperate multiple devices in a variable.
@@ -57,7 +57,7 @@ EFI_UNIX_PASS_THRU - associates a device with our PCI support
A 1.44MB emulated floppy with a block size of 1024 would look like:
EFI_UNIX_VIRTUAL_DISKS=RW;1440;1024
- Physical Disks: These devices use NT to open a real device in your system
+ Physical Disks: These devices use UNIX to open a real device in your system
Thus a 120 MB floppy would look like:
EFI_UNIX_PHYSICAL_DISKS=B:RW;245760;512
diff --git a/EdkUnixPkg/Dxe/UnixThunk/Bus/UnixBusDriver/UnixBusDriver.msa b/EdkUnixPkg/Dxe/UnixThunk/Bus/UnixBusDriver/UnixBusDriver.msa
index 2ca466c2c5..b64a8216de 100644
--- a/EdkUnixPkg/Dxe/UnixThunk/Bus/UnixBusDriver/UnixBusDriver.msa
+++ b/EdkUnixPkg/Dxe/UnixThunk/Bus/UnixBusDriver/UnixBusDriver.msa
@@ -132,7 +132,7 @@
<PcdEntry PcdItemType="DYNAMIC">
<C_Name>PcdUnixFileSystem</C_Name>
<TokenSpaceGuidCName>gEfiEdkUnixPkgTokenSpaceGuid</TokenSpaceGuidCName>
- <HelpText>This PCD defines the windows directory who will be mounted as
+ <HelpText>This PCD defines the unix directory who will be mounted as
harddisk in simulator.
The item type of this PCD can only be "DYNAMIC".</HelpText>
</PcdEntry>
diff --git a/EdkUnixPkg/Dxe/UnixThunk/Chipset/Metronome/Metronome.c b/EdkUnixPkg/Dxe/UnixThunk/Chipset/Metronome/Metronome.c
index be5d87d846..ee2aad0f66 100644
--- a/EdkUnixPkg/Dxe/UnixThunk/Chipset/Metronome/Metronome.c
+++ b/EdkUnixPkg/Dxe/UnixThunk/Chipset/Metronome/Metronome.c
@@ -15,7 +15,7 @@ Module Name:
Abstract:
- NT Emulation Metronome Architectural Protocol Driver as defined in DXE CIS
+ UNIX Emulation Metronome Architectural Protocol Driver as defined in DXE CIS
--*/
diff --git a/EdkUnixPkg/Dxe/UnixThunk/Chipset/Metronome/Metronome.h b/EdkUnixPkg/Dxe/UnixThunk/Chipset/Metronome/Metronome.h
index d82c825c6c..10e6dc9b8a 100644
--- a/EdkUnixPkg/Dxe/UnixThunk/Chipset/Metronome/Metronome.h
+++ b/EdkUnixPkg/Dxe/UnixThunk/Chipset/Metronome/Metronome.h
@@ -15,7 +15,7 @@ Module Name:
Abstract:
- NT Emulation Metronome Architectural Protocol Driver as defined in DXE CIS
+ UNIX Emulation Metronome Architectural Protocol Driver as defined in DXE CIS
--*/
diff --git a/EdkUnixPkg/Dxe/UnixThunk/Chipset/RealTimeClock/RealTimeClock.c b/EdkUnixPkg/Dxe/UnixThunk/Chipset/RealTimeClock/RealTimeClock.c
index 8cf60ebf99..12cbcc8ecc 100644
--- a/EdkUnixPkg/Dxe/UnixThunk/Chipset/RealTimeClock/RealTimeClock.c
+++ b/EdkUnixPkg/Dxe/UnixThunk/Chipset/RealTimeClock/RealTimeClock.c
@@ -15,7 +15,7 @@ Module Name:
Abstract:
- NT Emulation Architectural Protocol Driver as defined in Tiano
+ UNIX Emulation Architectural Protocol Driver as defined in Tiano
--*/
diff --git a/EdkUnixPkg/Dxe/UnixThunk/Chipset/Reset/Reset.c b/EdkUnixPkg/Dxe/UnixThunk/Chipset/Reset/Reset.c
index 8739d6cd1a..72c196bfd8 100644
--- a/EdkUnixPkg/Dxe/UnixThunk/Chipset/Reset/Reset.c
+++ b/EdkUnixPkg/Dxe/UnixThunk/Chipset/Reset/Reset.c
@@ -15,7 +15,7 @@ Module Name:
Abstract:
- Reset Architectural Protocol as defined in Tiano under NT Emulation
+ Reset Architectural Protocol as defined in Tiano under UNIX Emulation
--*/
diff --git a/EdkUnixPkg/Dxe/UnixThunk/Chipset/Timer/Timer.c b/EdkUnixPkg/Dxe/UnixThunk/Chipset/Timer/Timer.c
index 19fd911764..8001138b94 100644
--- a/EdkUnixPkg/Dxe/UnixThunk/Chipset/Timer/Timer.c
+++ b/EdkUnixPkg/Dxe/UnixThunk/Chipset/Timer/Timer.c
@@ -15,9 +15,9 @@ Module Name:
Abstract:
- NT Emulation Timer Architectural Protocol Driver as defined in DXE CIS
+ UNIX Emulation Timer Architectural Protocol Driver as defined in DXE CIS
- This Timer module uses an NT Thread to simulate the timer-tick driven
+ This Timer module uses an UNIX Thread to simulate the timer-tick driven
timer service. In the future, the Thread creation should possibly be
abstracted by the CPU architectural protocol
diff --git a/EdkUnixPkg/Dxe/UnixThunk/Chipset/Timer/Timer.h b/EdkUnixPkg/Dxe/UnixThunk/Chipset/Timer/Timer.h
index 98d1999b5b..37ff8b26b3 100644
--- a/EdkUnixPkg/Dxe/UnixThunk/Chipset/Timer/Timer.h
+++ b/EdkUnixPkg/Dxe/UnixThunk/Chipset/Timer/Timer.h
@@ -15,8 +15,8 @@ Module Name:
Abstract:
- NT Emulation Architectural Protocol Driver as defined in Tiano.
- This Timer module uses an NT Thread to simulate the timer-tick driven
+ UNIX Emulation Architectural Protocol Driver as defined in Tiano.
+ This Timer module uses an UNIX Thread to simulate the timer-tick driven
timer service.
--*/
diff --git a/EdkUnixPkg/Dxe/UnixThunk/Cpu/CpuDriver.h b/EdkUnixPkg/Dxe/UnixThunk/Cpu/CpuDriver.h
index 3a838a0c7f..d7254203d5 100644
--- a/EdkUnixPkg/Dxe/UnixThunk/Cpu/CpuDriver.h
+++ b/EdkUnixPkg/Dxe/UnixThunk/Cpu/CpuDriver.h
@@ -15,7 +15,7 @@ Module Name:
Abstract:
- NT Emulation Architectural Protocol Driver as defined in Tiano.
+ UNIX Emulation Architectural Protocol Driver as defined in Tiano.
--*/
diff --git a/EdkUnixPkg/Dxe/UnixThunk/Bus/Console/Console.h b/EdkUnixPkg/Dxe/UnixThunk/Bus/Console/Console.h
index 3f0b4eb6c8..a59c934a54 100644
--- a/EdkUnixPkg/Dxe/UnixThunk/Bus/Console/Console.h
+++ b/EdkUnixPkg/Dxe/UnixThunk/Bus/Console/Console.h
@@ -15,7 +15,7 @@ Module Name:
Abstract:
- Console based on Win32 APIs.
+ Console based on Posix APIs.
This file attaches a SimpleTextIn protocol to a previously open window.
@@ -44,7 +44,7 @@ typedef struct {
EFI_UNIX_THUNK_PROTOCOL *UnixThunk;
//
// SimpleTextOut Private Data including Win32 types.
//
// HANDLE NtOutHandle;
// HANDLE NtInHandle;
@@ -44,7 +44,7 @@ typedef struct {
EFI_UNIX_THUNK_PROTOCOL *UnixThunk;
//
- // SimpleTextOut Private Data including Win32 types.
+ // SimpleTextOut Private Data including Posix types.
//
// HANDLE NtOutHandle;
diff --git a/EdkUnixPkg/Dxe/UnixThunk/Bus/SimpleFileSystem/UnixSimpleFileSystem.c b/EdkUnixPkg/Dxe/UnixThunk/Bus/SimpleFileSystem/UnixSimpleFileSystem.c
index a1b5b32010..2a745cbdd2 100644
--- a/EdkUnixPkg/Dxe/UnixThunk/Bus/SimpleFileSystem/UnixSimpleFileSystem.c
+++ b/EdkUnixPkg/Dxe/UnixThunk/Bus/SimpleFileSystem/UnixSimpleFileSystem.c
@@ -15,8 +15,8 @@ Module Name:
Abstract:
- Produce Simple File System abstractions for directories on your PC using Win32 APIs.
- The configuration of what devices to mount or emulate comes from NT
+ Produce Simple File System abstractions for directories on your PC using Posix APIs.
+ The configuration of what devices to mount or emulate comes from UNIX
environment variables. The variables must be visible to the Microsoft*
Developer Studio for them to work.
@@ -1398,7 +1398,7 @@ Returns:
return EFI_SUCCESS;
//
// bugbug: need to access windows error reporting
//
}
@@ -2100,7 +2100,7 @@ Returns:
return PrivateFile->UnixThunk->FSync (PrivateFile->fd) == 0 ? EFI_SUCCESS : EFI_DEVICE_ERROR;
//
// bugbug: - Use Windows error reporting.
//
}
@@ -1398,7 +1398,7 @@ Returns:
return EFI_SUCCESS;
//
- // bugbug: need to access windows error reporting
+ // bugbug: need to access unix error reporting
//
}
@@ -2100,7 +2100,7 @@ Returns:
return PrivateFile->UnixThunk->FSync (PrivateFile->fd) == 0 ? EFI_SUCCESS : EFI_DEVICE_ERROR;
//
- // bugbug: - Use Windows error reporting.
+ // bugbug: - Use Unix error reporting.
//
}
diff --git a/EdkUnixPkg/Dxe/UnixThunk/Bus/UnixBusDriver/UnixBusDriver.c b/EdkUnixPkg/Dxe/UnixThunk/Bus/UnixBusDriver/UnixBusDriver.c
index 038c71a074..5346774ae2 100644
--- a/EdkUnixPkg/Dxe/UnixThunk/Bus/UnixBusDriver/UnixBusDriver.c
+++ b/EdkUnixPkg/Dxe/UnixThunk/Bus/UnixBusDriver/UnixBusDriver.c
@@ -15,9 +15,9 @@ Module Name:
Abstract:
-This following section documents the envirnoment variables for the Win NT
+This following section documents the envirnoment variables for the Win UNIX
build. These variables are used to define the (virtual) hardware
-configuration of the NT environment
+configuration of the UNIX environment
A ! can be used to seperate multiple instances in a variable. Each
instance represents a seperate hardware device.
@@ -35,7 +35,7 @@ EFI_UNIX_UGA - Builds UGA Windows of Width and Height
<block count> - Decimal number of blocks a device supports.
<block size> - Decimal number of bytes per block.
- NT envirnonment variable contents. '<' and '>' are not part of the variable,
+ UNIX envirnonment variable contents. '<' and '>' are not part of the variable,
they are just used to make this help more readable. There should be no
spaces between the ';'. Extra spaces will break the variable. A '!' is
used to seperate multiple devices in a variable.
@@ -55,7 +55,7 @@ EFI_UNIX_UGA - Builds UGA Windows of Width and Height
A 1.44MB emulated floppy with a block size of 1024 would look like:
EFI_UNIX_VIRTUAL_DISKS=RW;1440;1024
- Physical Disks: These devices use NT to open a real device in your system
+ Physical Disks: These devices use UNIX to open a real device in your system
Thus a 120 MB floppy would look like:
EFI_UNIX_PHYSICAL_DISKS=B:RW;245760;512
@@ -115,7 +115,7 @@ EFI_DRIVER_BINDING_PROTOCOL gUnixBusDriverBinding = {
#define UNIX_PCD_ARRAY_SIZE (sizeof(mPcdEnvironment)/sizeof(UNIX_PCD_ENTRY))
//
// Table to map NT Environment variable to the GUID that should be in
// device path.
//
static UNIX_PCD_ENTRY mPcdEnvironment[] = {
@@ -115,7 +115,7 @@ EFI_DRIVER_BINDING_PROTOCOL gUnixBusDriverBinding = {
#define UNIX_PCD_ARRAY_SIZE (sizeof(mPcdEnvironment)/sizeof(UNIX_PCD_ENTRY))
//
-// Table to map NT Environment variable to the GUID that should be in
+// Table to map UNIX Environment variable to the GUID that should be in
// device path.
//
diff --git a/EdkUnixPkg/Dxe/UnixThunk/Cpu/Cpu.c b/EdkUnixPkg/Dxe/UnixThunk/Cpu/Cpu.c
index 9149639abc..9166a8a0a2 100644
--- a/EdkUnixPkg/Dxe/UnixThunk/Cpu/Cpu.c
+++ b/EdkUnixPkg/Dxe/UnixThunk/Cpu/Cpu.c
@@ -70,7 +70,7 @@ UnixFlushCpuDataCache (
Routine Description:
This routine would provide support for flushing the CPU data cache.
- In the case of NT emulation environment, this flushing is not necessary and
+ In the case of UNIX emulation environment, this flushing is not necessary and
is thus not implemented.
Arguments:
@@ -92,13 +92,13 @@ Returns:
{
if (FlushType == EfiCpuFlushTypeWriteBackInvalidate) {
//
// Only WB flush is supported. We actually need do nothing on NT emulator
// environment. Classify this to follow EFI spec
//
return EFI_SUCCESS;
}
//
// Other flush types are not supported by NT emulator
//
return EFI_UNSUPPORTED;
}
@@ -92,13 +92,13 @@ Returns:
if (FlushType == EfiCpuFlushTypeWriteBackInvalidate) {
//
- // Only WB flush is supported. We actually need do nothing on NT emulator
+ // Only WB flush is supported. We actually need do nothing on UNIX emulator
// environment. Classify this to follow EFI spec
//
@@ -92,13 +92,13 @@ Returns:
}
//
- // Other flush types are not supported by NT emulator
+ // Other flush types are not supported by UNIX emulator
//
return EFI_UNSUPPORTED;